Index: src/image/SkImagePriv.h |
diff --git a/src/image/SkImagePriv.h b/src/image/SkImagePriv.h |
index 5d93605566991e4cb2c1de9cee99c76db134e92f..188b16d530fef1f9124d0bbb19ee6085e16a1e2a 100644 |
--- a/src/image/SkImagePriv.h |
+++ b/src/image/SkImagePriv.h |
@@ -13,14 +13,14 @@ |
class SkPicture; |
-extern SkBitmap::Config SkImageInfoToBitmapConfig(const SkImage::Info&); |
+extern SkBitmap::Config SkImageInfoToBitmapConfig(const SkImageInfo&); |
-extern int SkImageBytesPerPixel(SkImage::ColorType); |
+extern int SkImageBytesPerPixel(SkColorType); |
-extern bool SkBitmapToImageInfo(const SkBitmap&, SkImage::Info*); |
+extern bool SkBitmapToImageInfo(const SkBitmap&, SkImageInfo*); |
// Call this if you explicitly want to use/share this pixelRef in the image |
-extern SkImage* SkNewImageFromPixelRef(const SkImage::Info&, SkPixelRef*, |
+extern SkImage* SkNewImageFromPixelRef(const SkImageInfo&, SkPixelRef*, |
size_t rowBytes); |
/** |
@@ -30,7 +30,7 @@ extern SkImage* SkNewImageFromPixelRef(const SkImage::Info&, SkPixelRef*, |
* is true. |
* |
* If the bitmap's config cannot be converted into a corresponding |
* SkImage::Info, or the bitmap's pixels cannot be accessed, this will return |
* NULL. |
*/ |
extern SkImage* SkNewImageFromBitmap(const SkBitmap&, bool canSharePixelRef); |
@@ -47,7 +47,7 @@ extern void SkImagePrivDrawPicture(SkCanvas*, SkPicture*, |
*/ |
extern SkImage* SkNewImageFromPicture(const SkPicture*); |
-static inline size_t SkImageMinRowBytes(const SkImage::Info& info) { |
+static inline size_t SkImageMinRowBytes(const SkImageInfo& info) { |
size_t rb = info.fWidth * SkImageBytesPerPixel(info.fColorType); |
return SkAlign4(rb); |
} |
@@ -30,7 +30,7 @@ extern SkImage* SkNewImageFromPixelRef(const SkImage::Info&, SkPixelRef*, |
* |
* If the bitmap's config cannot be converted into a corresponding |
- * SkImage::Info, or the bitmap's pixels cannot be accessed, this will return |
+ * SkImageInfo, or the bitmap's pixels cannot be accessed, this will return |
* NULL. |
*/ |